@@ -1,5 +1,7 @@
+import sys
+
 import lief
-from lief import ELF, MachO, PE
+from lief import ELF, PE, MachO
 
 from blint.logger import LOG
 from blint.utils import calculate_entropy, check_secret, decode_base64
@@ -221,6 +223,85 @@ def parse_pe_data(parsed_obj):
         return None
 
 
+def process_pe_resources(parsed_obj):
+    try:
+        rm = parsed_obj.resources_manager
+        metadata = {
+            "has_accelerator": rm.has_accelerator,
+            "has_dialogs": rm.has_dialogs,
+            "has_html": rm.has_html,
+            "has_icons": rm.has_icons,
+            "has_manifest": rm.has_manifest,
+            "has_string_table": rm.has_string_table,
+            "has_version": rm.has_version,
+            "html": rm.html if rm.has_html else None,
+            "manifest": rm.manifest if rm.has_manifest else None,
+            "version_info": str(rm.version),
+        }
+        return metadata
+    except lief.exception as e:
+        print(e)
+        return None
+
+
+def process_pe_signature(parsed_obj):
+    try:
+        signature_list = []
+        for idx, sig in enumerate(parsed_obj.signatures):
+            ci = sig.content_info
+            signature_obj = {
+                "version": sig.version,
+                "digest_algorithm": str(sig.digest_algorithm),
+                "content_info": {
+                    "content_type": lief.PE.oid_to_string(ci.content_type),
+                    "digest_algorithm": str(ci.digest_algorithm),
+                    "digest": ci.digest.hex(),
+                },
+            }
+            signers_list = []
+            for signer in sig.signers:
+                signer_obj = {
+                    "version": signer.version,
+                    "serial_number": signer.serial_number.hex(),
+                    "issuer": str(signer.issuer),
+                    "digest_algorithm": str(signer.digest_algorithm),
+                    "encryption_algorithm": str(signer.encryption_algorithm),
+                    "encrypted_digest": signer.encrypted_digest.hex(),
+                }
+                signers_list.append(signer_obj)
+            signature_obj["signers"] = signers_list
+            signature_list.append(signature_obj)
+        return signature_list
+    except lief.exception:
+        return None
+
+
+def parse_pe_authenticode(parsed_obj):
+    try:
+        LOG.debug("Parsing authentihash")
+        authenticode = {}
+        sep = ":" if sys.version_info.minor > 7 else ()
+        authenticode["md5_hash"] = parsed_obj.authentihash_md5.hex(*sep)
+        authenticode["sha256_hash"] = parsed_obj.authentihash_sha256.hex(*sep)
+        authenticode["sha1_hash"] = parsed_obj.authentihash(
+            lief.PE.ALGORITHMS.SHA_1
+        ).hex(*sep)
+        authenticode["verification_flags"] = str(parsed_obj.verify_signature())
+        cert_signer_str = str(parsed_obj.signatures[0].signers[0].cert)
+        cert_signer_obj = {}
+        for p in cert_signer_str.split("\n"):
+            tmpA = p.split(" : ")
+            if len(tmpA) == 2:
+                tmpKey = tmpA[0].strip().replace(" ", "_")
+                if "version" in tmpKey:
+                    tmpKey = "version"
+                cert_signer_obj[tmpKey] = tmpA[1].strip()
+        authenticode["cert_signer"] = cert_signer_obj
+        return authenticode
+    except lief.exception:
+        return None
+
+
 def parse_pe_symbols(symbols):
     try:
         LOG.debug("Parsing symbols")
@@ -585,6 +666,18 @@ def parse(exe_file):
                 metadata["data_directories"] = parse_pe_data(parsed_obj)
             except lief.exception:
                 pass
+            try:
+                metadata["authenticode"] = parse_pe_authenticode(parsed_obj)
+            except lief.exception:
+                pass
+            try:
+                metadata["signatures"] = process_pe_signature(parsed_obj)
+            except lief.exception:
+                pass
+            try:
+                metadata["resources"] = process_pe_resources(parsed_obj)
+            except lief.exception:
+                pass
             try:
                 metadata["static_symbols"], exe_type = parse_pe_symbols(
                     parsed_obj.symbols
